@@ -1,6 +1,6 @@
 /* gnome-stones - object.h
  *
- * Time-stamp: <1998/11/09 19:34:12 carsten>
+ * Time-stamp: <2002/10/31 08:24:27 ross>
  *
  * Copyright (C) 1998 Carsten Schaar
  *
@@ -18,6 +18,11 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
+
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "object.h"
 
 #include <sys/types.h>
@@ -123,6 +128,9 @@ plugin_load (const gchar *filename)
 }
 
 
+#define SOEXT ("." G_MODULE_SUFFIX)
+#define SOEXT_LEN (strlen (SOEXT))
+
 void
 plugin_load_plugins_in_dir (const gchar *directory)
 {
@@ -134,8 +142,8 @@ plugin_load_plugins_in_dir (const gchar *directory)
   
   while ((e = readdir (d)) != NULL)
     {
-      if ((strlen (e->d_name) > 3) &&  
-	  (strncmp (e->d_name + strlen (e->d_name) - 3, ".so", 3) == 0))
+      if ((strlen (e->d_name) > SOEXT_LEN) &&  
+	  (strncmp (e->d_name + strlen (e->d_name) - SOEXT_LEN, SOEXT, SOEXT_LEN) == 0))
 	{
 	  char *objects_name;
 	  
@@ -178,13 +186,34 @@ static GStonesObjectDesc frame_description=
   0, 0
 };
 
+/*****************************************************************************/
+/* This is animated curtain.  */
+
+
+static GStonesObjectDesc curtain_description=
+{
+  "curtain",
+
+  NULL,
+  NULL,
+  
+  NULL,
+  NULL,
+  
+  "animated_curtain.png",
+  NULL,
+  0, 0
+};
+
 
 gchar *
 default_objects_init (GStonesPlugin *plugin)
 {
   object_register (plugin, &frame_description);
+  object_register (plugin, &curtain_description);
 
   return "default";
+
 }
 
 
@@ -235,7 +264,8 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
   object->plugin     = plugin;
 
   filename= g_strconcat ("gnome-stones/", description->image_name, NULL);
-  pathname= gnome_pixmap_file (filename);
+  pathname=  gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_APP_PIXMAP,
+                                        filename, TRUE, NULL);
   image   = gdk_pixbuf_new_from_file (pathname, NULL);
   g_free (pathname);
   g_free (filename);
@@ -282,7 +312,7 @@ object_register (GStonesPlugin *plugin, GStonesObjectDesc *description)
   
   object->pixbuf_image= g_malloc (num_x*num_y*sizeof (GdkPixbuf*));
   
-  if (object->image == NULL)
+  if (object->pixbuf_image == NULL)
     {
       char *error= g_strconcat ("Error while registering object ", 
 				   description->image_name, 
