@@ -4,9 +4,6 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gnome.h>
 #include "minefield.h"
-#include "flag.xpm"
-#include "mine.xpm"
-#include "question.xpm"
 
 static struct {
 	gint x;
@@ -75,7 +72,7 @@ static void gtk_minefield_unrealize (GtkWidget *widget);
 static void gtk_minefield_win(GtkMineField *mfield);
 static void init_random(gulong seed);
 static inline int gtk_minefield_check_cell(GtkMineField *mfield, guint x, guint y);
-static void _setup_sign (sign *signp, const char **data, guint minesize);
+static void _setup_sign (sign *signp, const char *file, guint minesize);
 static inline void gtk_minefield_multi_press(GtkMineField *mfield, guint x, guint y, gint c);
 /* end prototypes */
 
@@ -88,17 +85,17 @@ static inline gint cell_idx(GtkMineField *mfield, guint x, guint y)
 	return -1;
 }
 
-static void _setup_sign (sign *signp, const char **data, guint minesize)
+static void _setup_sign (sign *signp, const char *file, guint minesize)
 {
 	GdkPixbuf *image;
-
-	image = gdk_pixbuf_new_from_xpm_data ( (const char **) data);
+	/* TODO: catch GError */
+	image = gdk_pixbuf_new_from_file (file, NULL);
 
 	gdk_pixbuf_render_pixmap_and_mask (image, &signp->pixmap,
 					   &signp->mask, 127);
 
 	gdk_pixbuf_unref (image);
-        gdk_drawable_get_size(signp->pixmap, &(signp->width), &(signp->height));
+	gdk_drawable_get_size(signp->pixmap, &(signp->width), &(signp->height));
 }
 
 static void gtk_minefield_setup_signs(GtkWidget *widget)
@@ -107,9 +104,9 @@ static void gtk_minefield_setup_signs(GtkWidget *widget)
   
         mfield = GTK_MINEFIELD(widget);
   
-        _setup_sign(&mfield->flag, flag_xpm, mfield->minesize);
-        _setup_sign(&mfield->mine, mine_xpm, mfield->minesize);
-	_setup_sign(&mfield->question, question_xpm, mfield->minesize);
+        _setup_sign(&mfield->flag, DATADIR"/pixmaps/gnomine/flag.png", mfield->minesize);
+        _setup_sign(&mfield->mine, DATADIR"/pixmaps/gnomine/mine.png", mfield->minesize);
+        _setup_sign(&mfield->question, DATADIR"/pixmaps/gnomine/flag-question.png", mfield->minesize);
 }
 
 static void
@@ -144,9 +141,9 @@ gtk_minefield_setup_numbers(GtkMineField *mfield)
 
 		/* do the font */
 		font_desc = pango_font_description_new();
-		pango_font_description_set_family(font_desc, "Courier 8");
+		pango_font_description_set_family(font_desc, "Mono 8");
 		pango_font_description_set_size(font_desc,
-						pixel_sz * PANGO_SCALE);
+						pixel_sz * PANGO_SCALE * 0.7);
 		pango_font_description_set_weight(font_desc,PANGO_WEIGHT_BOLD);
 		attr = pango_attr_font_desc_new(font_desc);
 		pango_font_description_free(font_desc);
@@ -316,11 +313,12 @@ static void gtk_mine_draw(GtkMineField *mfield, guint x, guint y)
 
 	if (mfield->mines[c].shown && !mfield->mines[c].mined) {
 		if ((n = mfield->mines[c].neighbours) != 0) {
+			g_assert (n >= 0 && n <= 9);
 			gdk_draw_layout(widget->window,
 					widget->style->black_gc,
 					x*minesize + mfield->numstr[n].dx,
-					y*minesize + mfield->numstr[n].dy,
-					mfield->numstr[n].layout);
+					y*minesize + mfield->numstr[n].dy+1,
+					PANGO_LAYOUT(mfield->numstr[n].layout));
 		}
 
 	} else if (mfield->mines[c].marked == MINE_QUESTION) {
